==> nextcloud-31.0.9.tar.bz2: nextcloud/apps/activity/l10n/sl.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Osebne dejavnosti za %s",
    "Your feed URL is invalid" : "Spletni naslov vira ni veljaven",
    "Activity feed for %1$s" : "Vir dejavnosti za %1$s",
    "Activity feed" : "Objava dejavnosti z viri RSS",
    "Your settings have been updated." : "Nastavitve so posodobljene.",
    "Settings have been updated." : "Nastavitve so posodobljene.",
    "remote user" : "oddaljeni uporabnik",
    "Recent activity" : "Nedavna dejavnost",
    "No activities" : "Ni dejavnosti",
    "More activities" : "Več dejavnosti",
    "Daily activity summary for %s" : "Dnevni povzetek dejavnosti za račun %s",
    "_and %n more…_::_and %n more…_" : ["in %n drugo ...","in %n drugi ...","in %n druge ...","in %n drugih ..."],
    "All activities" : "Vse dejavnosti",
    "By others" : "Dejavnosti drugih",
    "By you" : "Moje dejavnosti",
    "Activity at %s" : "Dejavnosti ob %s",
    "Hello %s" : "Pozdravljeni, %s,",
    "Hello %s," : "Pozdravljeni, %s,",
    "There was some activity at %s" : "V oblaku %s se je nekaj dogajalo ...",
    "_and %n more _::_and %n more _" : ["- in še %n","- in še %n","- in še %n","– in še %n"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Spremeniti je mogoče pogostost prejemanja teh sporočil oziroma jih v celoti onemogočiti. Možnosti so med <a href=\"%s\">nastavitvami</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Spremeniti je mogoče pogostost prejemanja teh sporočil oziroma jih v celoti onemogočiti. Možnosti so med nastavitvami: %s",
    "Mail" : "Elektronska pošta",
    "Push" : "Potisno",
    "Activity" : "Dejavnosti",
    "Notifications" : "Obvestila",
    "This application enables people to view a log of activities about them, their files or other data." : "Program omogoča pregled dnevnikov dejavnosti, dela, datotek in drugih zbranih podatkov.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Program omogoča pregled dejavnosti, povezanih z delom, datotekami in drugimi podatki v oblaku Nextcloud.\n\t\tVsak uporabnik lahko izbere in prilagodi nastavitve dejavnosti,\n\t\tvrsto in način obveščanja na napravah ali z elektronsko pošto,\n\t\tlahko tudi kot dnevni povzetek obvestil.\n\t\tVeč podrobnosti je zapisanih v dokumentaciji.",
    "Send email" : "Pošlji elektronsko sporočilo",
    "Send push notification" : "Pošlji potisno obvestilo",
    "Activity notification configuration" : "Nastavitve obveščanja o dejavnosti",
    "Today" : "Danes",
    "Yesterday" : "Včeraj",
    "You need to set up your email address before you can receive notification emails." : "Za prejemanje obvestil po elektronski pošti je treba najprej nastaviti elektronski poštni naslov.",
    "Send activity emails" : "Pošiljaj obvestila o dejavnosti na elektronske naslove",
    "As soon as possible" : "Čimprej",
    "Hourly" : "Vsako uro",
    "Daily" : "Dnevno",
    "Weekly" : "Tedensko",
    "You commented" : "Napišete opombo",
    "Message deleted by author" : "Sporočilo je avtor izbrisal.",
    "Open {filename}" : "Odpri {filename}",
    "in {path}" : "v {pot}",
    "Home" : "Začetni pogled",
    "Could not load activities" : "Dejavnosti ni mogoče naložiti.",
    "Loading activities" : "Nalaganje dejavnosti",
    "This stream will show events like additions, changes & shares" : "V tem pretoku bodo pokazani dogodki, kot so dodajanja, spremembe in spreminjanje souporabe.",
    "No activity yet" : "Ni še zabeležene dejavnosti",
    "Loading more activities" : "Nalaganje več dejavnosti",
    "No more activities." : "Ni drugih  zabeleženih dejavnosti.",
    "Could not enable RSS link" : "Ni mogoče odpreti povezave RSS",
    "RSS link copied to clipboard" : "Povezava RSS je kopirana v odložišče.",
    "Could not copy the RSS link, please copy manually:" : "Povezave RSS ni mogoče kopirati. Storite to ročno:",
    "Activity settings" : "Nastavitve dejavnosti",
    "Enable RSS feed" : "Omogoči vire RSS",
    "RSS feed" : "Viri RSS",
    "Copy RSS feed link" : "Kopiraj povezavo vira RSS",
    "Personal notification settings" : "Osebne nastavitve obveščanja",
    "Unable to load the activity list" : "Seznama dejavnosti ni mogoče naložiti ",
    "Choose for which activities you want to get an email or push notification." : "Za katere dejavnosti želite prejeti sporočilo na elektronski naslov ali pa potisno obvestilo na napravi.",
    "Choose for which activities you want to get a push notification." : "Za katere dejavnosti želite prejeti potisno obvestilo na napravi.",
    "Notification" : "Obvestilo",
    "Enable notification emails" : "Omogoči obveščanje prek elektronske pošte",
    "Daily activity summary" : "Dnevni povzetek dejavnosti",
    "Send daily activity summary in the morning" : "Povzetke dnevne dejavnosti pošiljaj zjutraj",
    "Default settings" : "Prevzete nastavitve",
    "Configure the default notification settings for new accounts." : "Prilagodi privzete nastavitve obveščanja za nove uporabnike.",
    "Unable to save the settings" : "Nastavitev ni mogoče shraniti",
    "No more events to load" : "Ni načrtovanih drugih dogodkov"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-32.0.3.tar.bz2: nextcloud/apps/activity/l10n/sl.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Osebne dejavnosti za %s",
    "Your feed URL is invalid" : "Spletni naslov vira ni veljaven",
    "Activity feed for %1$s" : "Vir dejavnosti za %1$s",
    "Activity feed" : "Objava dejavnosti z viri RSS",
    "Your settings have been updated." : "Nastavitve so posodobljene.",
    "Settings have been updated." : "Nastavitve so posodobljene.",
    "remote user" : "oddaljeni uporabnik",
    "Recent activity" : "Nedavna dejavnost",
    "No activities" : "Ni dejavnosti",
    "More activities" : "Več dejavnosti",
    "Daily activity summary for %s" : "Dnevni povzetek dejavnosti za račun %s",
    "_and %n more…_::_and %n more…_" : ["in %n drugo ...","in %n drugi ...","in %n druge ...","in %n drugih ..."],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Pošiljanje sporočil s povzetki dneva je mogoče prilagoditi med <a href=\"%s\">nastavitvami</a>.",
    "You can disable daily digest emails in the settings: %s" : "Pošiljanje sporočil s povzetki dneva je mogoče prilagoditi med nastavitvami: %s",
    "All activities" : "Vse dejavnosti",
    "By others" : "Dejavnosti drugih",
    "By you" : "Moje dejavnosti",
    "Activity at %s" : "Dejavnosti ob %s",
    "Hello %s" : "Pozdravljeni, %s,",
    "Hello %s," : "Pozdravljeni, %s,",
    "There was some activity at %s" : "V oblaku %s se je nekaj dogajalo ...",
    "_and %n more _::_and %n more _" : ["- in še %n","- in še %n","- in še %n","– in še %n"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Spremeniti je mogoče pogostost prejemanja teh sporočil oziroma jih v celoti onemogočiti. Možnosti so med <a href=\"%s\">nastavitvami</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Spremeniti je mogoče pogostost prejemanja teh sporočil oziroma jih v celoti onemogočiti. Možnosti so med nastavitvami: %s",
    "Mail" : "Elektronska pošta",
    "Push" : "Potisno",
    "Activity" : "Dejavnosti",
    "Notifications" : "Obvestila",
    "This application enables people to view a log of activities about them, their files or other data." : "Program omogoča pregled dnevnikov dejavnosti, dela, datotek in drugih zbranih podatkov.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Program omogoča pregled dejavnosti, povezanih z delom, datotekami in drugimi podatki v oblaku Nextcloud.\n\t\tVsak uporabnik lahko izbere in prilagodi nastavitve dejavnosti,\n\t\tvrsto in način obveščanja na napravah ali z elektronsko pošto,\n\t\tlahko tudi kot dnevni povzetek obvestil.\n\t\tVeč podrobnosti je zapisanih v dokumentaciji.",
    "Send email" : "Pošlji elektronsko sporočilo",
    "Send push notification" : "Pošlji potisno obvestilo",
    "Activity notification configuration" : "Nastavitve obveščanja o dejavnosti",
    "Today" : "Danes",
    "Yesterday" : "Včeraj",
    "You need to set up your email address before you can receive notification emails." : "Za prejemanje obvestil po elektronski pošti je treba najprej nastaviti elektronski poštni naslov.",
    "Send activity emails" : "Pošiljaj obvestila o dejavnosti na elektronske naslove",
    "As soon as possible" : "Čimprej",
    "Hourly" : "Vsako uro",
    "Daily" : "Dnevno",
    "Weekly" : "Tedensko",
    "You commented" : "Napišete opombo",
    "Message deleted by author" : "Sporočilo je avtor izbrisal.",
    "Open {filename}" : "Odpri {filename}",
    "in {path}" : "v {pot}",
    "Home" : "Začetni pogled",
    "Could not load activities" : "Dejavnosti ni mogoče naložiti.",
    "Loading activities" : "Nalaganje dejavnosti",
    "This stream will show events like additions, changes & shares" : "V tem pretoku bodo pokazani dogodki, kot so dodajanja, spremembe in spreminjanje souporabe.",
    "No activity yet" : "Ni še zabeležene dejavnosti",
    "Loading more activities" : "Nalaganje več dejavnosti",
    "No more activities." : "Ni drugih  zabeleženih dejavnosti.",
    "Could not enable RSS link" : "Ni mogoče odpreti povezave RSS",
    "RSS link copied to clipboard" : "Povezava RSS je kopirana v odložišče.",
    "Could not copy the RSS link, please copy manually:" : "Povezave RSS ni mogoče kopirati. Storite to ročno:",
    "Activity settings" : "Nastavitve dejavnosti",
    "Enable RSS feed" : "Omogoči vire RSS",
    "RSS feed" : "Viri RSS",
    "Copy RSS feed link" : "Kopiraj povezavo vira RSS",
    "Personal notification settings" : "Osebne nastavitve obveščanja",
    "Unable to load the activity list" : "Seznama dejavnosti ni mogoče naložiti ",
    "Choose for which activities you want to get an email or push notification." : "Za katere dejavnosti želite prejeti sporočilo na elektronski naslov ali pa potisno obvestilo na napravi.",
    "Choose for which activities you want to get a push notification." : "Za katere dejavnosti želite prejeti potisno obvestilo na napravi.",
    "Notification" : "Obvestilo",
    "Enable notification emails" : "Omogoči obveščanje prek elektronske pošte",
    "Daily activity summary" : "Dnevni povzetek dejavnosti",
    "Send daily activity summary in the morning" : "Povzetke dnevne dejavnosti pošiljaj zjutraj",
    "Default settings" : "Prevzete nastavitve",
    "Configure the default notification settings for new accounts." : "Prilagodi privzete nastavitve obveščanja za nove uporabnike.",
    "Unable to save the settings" : "Nastavitev ni mogoče shraniti",
    "No more events to load" : "Ni načrtovanih drugih dogodkov"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
